@@ -1,7 +1,7 @@
 import os
+import posixpath
 from raft import task
 from raft.collection import Collection
-import posixpath
 
 
 @task
@@ -76,8 +76,8 @@ def pan(ctx, host, bucket, namespace, cert,
     response = session.post(base_url, params=params, data=data, files=files)
     print(f'{response.text}')
 
-    print(f'committing')
-    xml = f'<commit><description>imported certificate from secure_sedge</description></commit>'
+    print('committing')
+    xml = '<commit><description>imported certificate from secure_sedge</description></commit>'
     data = {
         'type': 'commit',
         'cmd': xml,
@@ -87,6 +87,28 @@ def pan(ctx, host, bucket, namespace, cert,
     print(f'{response.text}')
 
 
+@task
+def linux(ctx, bucket, cert_key, private_key, services, profile=None):
+    """
+    installs certs to /etc/ssl/certs
+    installs keys to /etc/ssl/private
+    services is a comma separated list of services to reload once
+    the keys have been updated
+    """
+    from boto3 import Session
+    session = Session(profile_name=profile)
+    s3 = session.client('s3')
+    filename = os.path.join('/etc/ssl', os.path.basename(cert_key))
+    s3.download_file(bucket, cert_key, filename)
+    filename = os.path.join('/etc/ssl', os.path.basename(private_key))
+    s3.download_file(bucket, private_key, filename)
+    services = services.split(',')
+    services = [ x.strip() for x in services ]
+    for x in services:
+        ctx.run(f'systemctl reload {x}')
+
+
 installers_collection = Collection(
     pan,
+    linux,
 )
