@@ -1,6 +1,6 @@
+from importlib.resources import open_text
 from logging.config import dictConfig
 from raft import Collection, Program
-from .versioning import version
 from . import sewer
 from . import installers
 
@@ -44,4 +44,4 @@ dictConfig(dict(
 ))
 ns = Collection.from_module(sewer)
 ns.add_collection(installers.installers_collection, 'install')
-program = Program(version=version, namespace=ns)
+program = Program(version=open_text('sedge', 'version.txt').read(), namespace=ns)
