@@ -353,7 +353,7 @@ def renew_all(ctx, dir_name=None, profile=None):
             if filename.endswith('defaults.yml'):
                 continue
             request_cert(ctx, filename, profile, defaults)
-        except:
+        except:  # noqa: E722, pylint: disable=bare-except, broad-except
             pass
 
 
